0.2.37 (2024-07-20)
-------------------

Bugfixes and new subtitle field for blog and podcast.

- #159 Fixed author name in post detail page header for bs4 and base templates
- #160 Squash migrations
